about summary refs log tree commit diff
path: root/src/bootstrap/bootstrap.py
diff options
context:
space:
mode:
authorSebastian Widua <seppel3210@gmail.com>2021-06-12 23:47:17 +0200
committerSebastian Widua <seppel3210@gmail.com>2021-06-12 23:47:17 +0200
commitc8f5d6d80d397334eb613cf3e414028af68f3f02 (patch)
treec859f2b8272a054cda20323f113e6ae78f73f37f /src/bootstrap/bootstrap.py
parentb5e92756b305c6ec4bdd42feddd013333eb69d63 (diff)
parentda7ada584a3e5c3467b8b9f344b4a0f2a81ce32a (diff)
downloadrust-c8f5d6d80d397334eb613cf3e414028af68f3f02.tar.gz
rust-c8f5d6d80d397334eb613cf3e414028af68f3f02.zip
Merge branch 'master' of https://github.com/rust-lang/rust
Diffstat (limited to 'src/bootstrap/bootstrap.py')
-rw-r--r--src/bootstrap/bootstrap.py8
1 files changed, 5 insertions, 3 deletions
diff --git a/src/bootstrap/bootstrap.py b/src/bootstrap/bootstrap.py
index 149a899cef7..7c7f162b82c 100644
--- a/src/bootstrap/bootstrap.py
+++ b/src/bootstrap/bootstrap.py
@@ -648,18 +648,20 @@ class RustBuild(object):
         rev_parse = ["git", "rev-parse", "--show-toplevel"]
         top_level = subprocess.check_output(rev_parse, universal_newlines=True).strip()
         compiler = "{}/compiler/".format(top_level)
+        library = "{}/library/".format(top_level)
 
         # Look for a version to compare to based on the current commit.
         # Only commits merged by bors will have CI artifacts.
         merge_base = ["git", "log", "--author=bors", "--pretty=%H", "-n1"]
         commit = subprocess.check_output(merge_base, universal_newlines=True).strip()
 
-        # Warn if there were changes to the compiler since the ancestor commit.
-        status = subprocess.call(["git", "diff-index", "--quiet", commit, "--", compiler])
+        # Warn if there were changes to the compiler or standard library since the ancestor commit.
+        status = subprocess.call(["git", "diff-index", "--quiet", commit, "--", compiler, library])
         if status != 0:
             if download_rustc == "if-unchanged":
                 return None
-            print("warning: `download-rustc` is enabled, but there are changes to compiler/")
+            print("warning: `download-rustc` is enabled, but there are changes to \
+                   compiler/ or library/")
 
         if self.verbose:
             print("using downloaded stage1 artifacts from CI (commit {})".format(commit))